@@ -203,12 +203,6 @@ pytest 3.7.3 Pytest package
             f"--only {MAIN_GROUP}",
             """\
 cachy 0.1.0 Cachy package
-""",
-        ),
-        (
-            "--no-dev",
-            """\
-cachy 0.1.0 Cachy package
 """,
         ),
         (
@@ -295,11 +289,11 @@ def test_show_basic_with_installed_packages_single(
 
     tester.execute("cachy")
 
-    assert [
+    assert [line.strip() for line in tester.io.fetch_output().splitlines()] == [
         "name         : cachy",
         "version      : 0.1.0",
         "description  : Cachy package",
-    ] == [line.strip() for line in tester.io.fetch_output().splitlines()]
+    ]
 
 
 def test_show_basic_with_installed_packages_single_canonicalized(
@@ -337,11 +331,11 @@ def test_show_basic_with_installed_packages_single_canonicalized(
 
     tester.execute("Foo_Bar")
 
-    assert [
+    assert [line.strip() for line in tester.io.fetch_output().splitlines()] == [
         "name         : foo-bar",
         "version      : 0.1.0",
         "description  : Foobar package",
-    ] == [line.strip() for line in tester.io.fetch_output().splitlines()]
+    ]
 
 
 def test_show_basic_with_not_installed_packages_non_decorated(
@@ -1981,7 +1975,7 @@ dependencies
  - msgpack-python >=0.5 <0.6
 
 required by
- - pendulum >=0.2.0 <0.3.0
+ - pendulum requires >=0.2.0 <0.3.0
 """.splitlines()
     actual = [line.rstrip() for line in tester.io.fetch_output().splitlines()]
     assert actual == expected
@@ -2070,7 +2064,9 @@ def test_url_dependency_is_not_outdated_by_repository_package(
     installed: Repository,
     repo: TestRepository,
 ) -> None:
-    demo_url = "https://python-poetry.org/distributions/demo-0.1.0-py2.py3-none-any.whl"
+    demo_url = (
+        "https://files.pythonhosted.org/distributions/demo-0.1.0-py2.py3-none-any.whl"
+    )
     poetry.package.add_dependency(
         Factory.create_dependency(
             "demo",
@@ -2167,7 +2163,7 @@ def test_show_top_level(
     assert tester.io.fetch_output() == expected
 
 
-def test_show_top_level_with_explicitly_defined_depenancy(
+def test_show_top_level_with_explicitly_defined_dependency(
     tester: CommandTester, poetry: Poetry, installed: Repository
 ) -> None:
     poetry.package.add_dependency(Factory.create_dependency("a", "^0.1.0"))
